//@line 36 "/builds/tinderbox/Fx-Trunk-Cairo/Linux_2.4.21-32.0.1.EL_Depend/mozilla/browser/locales/../../browser/locales/en-US/firefox-l10n.js"

//@line 38 "/builds/tinderbox/Fx-Trunk-Cairo/Linux_2.4.21-32.0.1.EL_Depend/mozilla/browser/locales/../../browser/locales/en-US/firefox-l10n.js"

pref("general.useragent.locale", "en-US");
